@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2011 Utku Aydın <utkuaydin34@gmail.com>
+// SPDX-FileCopyrightText: 2011 Utku Aydın <utkuaydin34@gmail.com>
 //
 
 #include "DgmlTextureTagWriter.h"
@@ -57,12 +52,17 @@ bool DgmlTextureTagWriter::write(const GeoNode *node, GeoWriter& writer) const
         {
             QString protocol = texture->downloadUrls().at(i).toString().left(texture->downloadUrls().at(i).toString().indexOf(QLatin1Char(':')));
             QString host =  QString( texture->downloadUrls().at(i).host() );
+            int port =  texture->downloadUrls().at(i).port();
             QString path =  QString( texture->downloadUrls().at(i).path() );
             QString query = texture->downloadUrls().at(i).query(QUrl::FullyEncoded);
 
             writer.writeStartElement( dgml::dgmlTag_DownloadUrl );
             writer.writeAttribute( "protocol", protocol );
             writer.writeAttribute( "host", host );
+            if( port != -1 )
+            {
+                writer.writeAttribute( "port", QString::number( port ) );
+            }
             writer.writeAttribute( "path", path );
             writer.writeAttribute( "query", query );
             writer.writeEndElement();
